@@ -29,7 +29,7 @@ class SubRipItem(object):
 
     def shift(self, *args, **kwargs):
         """
-        shift(hours, minutes, seconds, micro_seconds)
+        shift(hours, minutes, seconds, milliseconds)
 
         Add given values to start and end attributes.
         All arguments are optional and have a default value of 0.
@@ -41,7 +41,7 @@ class SubRipItem(object):
     def from_string(cls, source):
         match = cls.RE_ITEM.match(source)
         if not match:
-            raise InvalidItem
+            raise InvalidItem(source)
 
         data = dict(match.groupdict())
         for group in ('start', 'end'):
